@@ -27,6 +27,7 @@
 #include <kurlrequester.h>
 #include <kshellcompletion.h>
 #include <ktoolbar.h>
+#include <KMessageBox>
 #include <krun.h>
 #include <QUrl>
 
@@ -228,6 +229,7 @@ void SignatureConfigurator::Private::init()
     hlay = new QHBoxLayout(); // inherits spacing
     page_vlay->addLayout(hlay);
     mFileRequester = new KUrlRequester(page);
+    mFileRequester->setFilter(QStringLiteral("*.txt"));
     mFileRequester->setWhatsThis(
         i18n("Use this requester to specify a text file that contains your "
              "signature. It will be read every time you create a new mail or "
@@ -237,7 +239,8 @@ void SignatureConfigurator::Private::init()
     hlay->addWidget(label);
     hlay->addWidget(mFileRequester, 1);
     mFileRequester->button()->setAutoDefault(false);
-    q->connect(mFileRequester, &KUrlRequester::textChanged, q, &SignatureConfigurator::slotEnableEditButton);
+    q->connect(mFileRequester, &KUrlRequester::textEdited, q, &SignatureConfigurator::slotUrlChanged);
+    q->connect(mFileRequester, &KUrlRequester::urlSelected, q, &SignatureConfigurator::slotUrlChanged);
     mEditButton = new QPushButton(i18n("Edit &File"), page);
     mEditButton->setWhatsThis(i18n("Opens the specified file in a text editor."));
     q->connect(mEditButton, &QPushButton::clicked, q, &SignatureConfigurator::slotEdit);
@@ -348,6 +351,7 @@ QString SignatureConfigurator::filePath() const
 void SignatureConfigurator::setFileURL(const QString &url)
 {
     d->mFileRequester->setUrl(QUrl::fromLocalFile(url));
+    d->mEditButton->setDisabled(url.trimmed().isEmpty());
 }
 
 QString SignatureConfigurator::commandPath() const
@@ -422,9 +426,14 @@ void SignatureConfigurator::setSignature(const Signature &sig)
     }
 }
 
-void SignatureConfigurator::slotEnableEditButton(const QString &url)
+void SignatureConfigurator::slotUrlChanged()
 {
-    d->mEditButton->setDisabled(url.trimmed().isEmpty());
+    const QString file = filePath();
+    const QFileInfo infoFile = QFileInfo(file);
+    if (infoFile.isFile() && (infoFile.size() > 1000)) {
+        KMessageBox::information(this, i18n("This text file size exceeds 1kb."), i18n("Text File Size"));
+    }
+    d->mEditButton->setDisabled(file.isEmpty());
 }
 
 void SignatureConfigurator::slotEdit()
